@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2013 Zuza Software Foundation
 #
@@ -22,6 +21,7 @@
 .. seealso:: http://en.wikipedia.org/wiki/N'Ko_language
 """
 
+
 import re
 
 from translate.lang import common
@@ -29,27 +29,28 @@ from translate.lang import common
 
 def reverse_quotes(text):
     def convertquotation(match):
-        return u"”%s“" % match.group(1)
-    return re.sub(u'“([^”]+)”', convertquotation, text)
+        return "”%s“" % match.group(1)
+
+    return re.sub("“([^”]+)”", convertquotation, text)
 
 
 class nqo(common.Common):
     """This class represents N'Ko."""
 
-    listseperator = u"߸ "
+    listseperator = "߸ "
 
     puncdict = {
-        u",": u"߸",
-        u";": u"؛",
-        u"?": u"؟",
-        u"!": u"߹",
+        ",": "߸",
+        ";": "؛",
+        "?": "؟",
+        "!": "߹",
     }
 
     ignoretests = {
-        'all': ["acronyms", "simplecaps", "startcaps"],
+        "all": ["acronyms", "simplecaps", "startcaps"],
     }
 
     @classmethod
     def punctranslate(cls, text):
-        text = super(cls, cls).punctranslate(text)
+        text = super().punctranslate(text)
         return reverse_quotes(text)
